/********************************************************************************
 Author : china customer centor (china.support@analog.com)
					China Applications Support Team 

 Date :   July 2014

 File name : AD5693R.c

 Description : This executable file contains definitions of all the functions defined in the header file ADuCM360Driver.h

 Hardware plateform : ADuCM360 	+ AD5693R
********************************************************************************/


#include "ADuCM360.h"
#include "ADuCM360Driver.h"

#include <stdio.h>
#include <string.h>

#include "AD5693R.h"
#include "spilib.h"
#include "ClkLib.h"
#include "DioLib.h"
#include "WdtLib.h"
#include "I2cLib.h"
#include "UrtLib.h"

unsigned char ucComRx = 0;
//unsigned char ucTxBufferEmpty  = 0;       // Used to indicate that the UART Tx buffer is empty
//unsigned char szTemp[16] = "";            // Used to store string before printing to UART
unsigned char nLen = 0;
unsigned char i = 0;
unsigned char ucWaitForUart = 0;          // Used by calibration routines to wait for user input
unsigned char ucWaitForRX = 0;          //


//Initializing AD5693R to default settings
void InitializeAD5693R(void)
{
	ADuCM360GpioOutput  (AD5693R_RESET, PIN_LOW); 
	Delay(100);
	ADuCM360GpioOutput  (AD5693R_RESET, PIN_HIGH); 
	Delay(100);
}
//Function for Initializing/Configuring LDAC pin for Hardware use 
void LdacInitialization(void)
	{	
			ADuCM360GpioOutput  (AD5693R_LDAC, PIN_HIGH); 
			Delay(100);
			ADuCM360GpioOutput  (AD5693R_LDAC, PIN_LOW); 
			Delay(100);
	}

//Function for writing input register (uses Command 1(0x1) or 4(0x4) to write based on the requirement)
/**
	@brief void WriteData(unsigned int commandmode,unsigned int Data)
	- Writes the data to the DAC with the selected mode of writing
	@param commandmode: {REG_WRITE_TO_INPUTREG,REG_WRITE_UPDATE_DAC,REG_WRITE_UPDATE_DAC}
		-REG_WRITE_TO_INPUTREG             //Command 1: Writes the data to the input register(LDAC dependent)
		-REG_UPDATE_DACREG_WITH_INPUTREG   //Command 2: Update DAC register (software LDAC)
	  -REG_WRITE_UPDATE_DAC              //Command 3: Writes and update the DAC channel(independent of LDAC)
	  -REG_WRITE_TO_CONTROLREG           //Command 4: Writes the data to the control register
	@param Data : {0xFFC0 - 0x0000}
	@param: addr: (0x98, 0x9c)
					- Address of AD5693R
	@ no return value
**/
void WriteData(unsigned int commandmode,unsigned int Data,unsigned char addr)
{
	  unsigned int arr[3]={0x00,0x00,0x00},brr[3]={0x00,0x00,0x00};
	  arr[0] = commandmode;
    arr[1] = Data & 0xFF00;
	  arr[1] >>= 8;
	  arr[2] = Data & 0x00FF;
	  I2cFunction(arr,brr,3,Send,addr);
}

//Function for Powerdown/ Power up DAC
/**
	@brief void PowerDownReg(unsigned int DACAmode)
	- Writes the values to Power down/Power up register
  @param DACAmode : {PD_DACA_NORMALMODE, PD_DACA_1K_TO_GND, PD_DACA_100K_TO_GND, PD_DACA_THREE_STATE}
    - PD_DACA_NORMALMODE     //puts DAC in normal mode
    - PD_DACA_1K_TO_GND      //puts DAC in powerdown : 1k to GND
    - PD_DACA_100K_TO_GND    //puts DAC in powerdown : 100k to GND
    - PD_DACA_THREE_STATE    //puts DAC in powerdown : Three state
	@param: addr: (0x98, 0x9c)
					- Address of AD5693R
 	@ no return value
**/
void PowerDownReg(unsigned int DACAmode,unsigned char addr)
{
		unsigned int arr[3]={0x00,0x00,0x00},brr[3]={0x00,0x00,0x00};
    arr[0] = REG_WRITE_TO_CONTROL;	
	  arr[1] = DACAmode;
    arr[2] = 0x00;
	  I2cFunction(arr,brr,3,Send,addr);
}
//Function for Software Reset (Power-on reset)
/**
	@brief void SoftwareReset(void)
	- Writes the values to Software Reset register.
	@param no parameters
	@param: addr: (0x98, 0x9c)
					- Address of AD5693R
 	@ no return value
**/
void SoftwareReset(unsigned char addr)
{
	  unsigned int arr[3]={0x00,0x00,0x00},brr[3]={0x00,0x00,0x00};
    arr[0] = REG_WRITE_TO_CONTROL;	
	  arr[1] = REG_SOFTWARE_RESET;
    arr[2] = 0x00;
	  I2cFunction(arr,brr,3,Send,addr);
	
}
//Function for Internal Reference setup
/**
	@brief void InternalReferenceSetup(unsigned int IntRefState)
	- Writes the values to Internal Reference setup register.
	@param IntRefState :{INTREF_ON, INTREF_OFF}
		- INTREF_ON    //Turns ON internal reference
    - INTREF_OFF   //Turns OFF internal reference
	@param: addr: (0x98, 0x9c)
					- Address of AD5693R
 	@ no return value
**/

void InternalReferenceSetup(unsigned int IntRefState,unsigned char addr)
{
	  unsigned int arr[3]={0x00,0x00,0x00},brr[3]={0x00,0x00,0x00};
    arr[0] = REG_WRITE_TO_CONTROL;	
	  arr[1] = IntRefState;
    arr[2] = 0x00;
	  I2cFunction(arr,brr,3,Send,addr);
}
//Function for gain of the output amplifier
/**
	@brief OutputAmplifierGain(unsigned int OutputGain)
	- Writes the values to select the gain of output amplifier
	@param OutputGain :{GAIN_1, GAIN_2}
		- GAIN_1    //Output range 0V to Vref
    - GAIN_2    //Output range 0V to 2*Vref
 	@ no return value
**/
void OutputAmplifierGain(unsigned int OutputGain,unsigned char addr)
{
	  unsigned int arr[3]={0x00,0x00,0x00},brr[3]={0x00,0x00,0x00};
    arr[0] = REG_WRITE_TO_CONTROL;	
	  arr[1] = OutputGain;
    arr[2] = 0x00;
	  I2cFunction(arr,brr,3,Send,addr);
}

unsigned char ReadBack(unsigned char RdacNo, unsigned char source, unsigned char addr)
{
	unsigned int arr[2]={0x00,0x00},brr[2]={0x00,0x00},temp=0x0000,info=0x0000;
	temp = 0x03;
	temp <<= 12;
	info |= temp;
	temp = 0x00;
	temp |= RdacNo;
	temp <<= 8;
	info |= temp;
	temp = 0x00;
	info |= source;
	arr[0] = info & 0xFF00;
	arr[0] >>= 8;
	arr[1] = info & 0x00FF;

  I2cFunction(arr,brr,2,Send,addr);

	I2cFunction(arr,brr,2,Receive,addr);
	
	return(brr[0]);
}





