/********************************************************************************
 Author : china customer centor (china.support@analog.com)
					China Applications Support Team 

 Date :   July 2014

 File name : ADuCM360Driver.c

 Description : This executable file contains definitions of all the functions defined in the header file ADuCM360Driver.h

 Hardware plateform : ADuCM360 	+ AD5693R
********************************************************************************/

#ifndef AD5693R_H
#define AD5693R_H


//REGISTER MAP

#define NO_OF_BYTES 0x03 //Size of Register in Bytes

//Hardware/Software LDAC
#define HardwareLDAC          //keep this uncommented for using Hardware LDAC. Comment this to use software LDAC.

#define PIN_HIGH 0x1
#define PIN_LOW  0x0

#define REG_WRITE_TO_INPUTREG               0x10    //Command 1: Write to input register n (LDAC dependent)
#define REG_UPDATE_DACREG_WITH_INPUTREG     0x20    //Command 2: Update DAC register with Input register
#define REG_WRITE_UPDATE_DAC                0x30    //Command 3: Write DAC and input registers.
#define	REG_WRITE_TO_CONTROL                0x40    //Command 4: Write control register

//select the gain of the output amplifier
#define GAIN_1   0x00
#define GAIN_2   0x08 

//INTERNAL REFERENCE
#define INTREF_ON    0x00     // Turns Internal Reference ON
#define INTREF_OFF   0x10     // Turns Internal Reference OFF

//POWERDOWN REGISTER
#define PD_DACA_NORMALMODE     0x00   //Puts DAC in normal mode
#define PD_DACA_1K_TO_GND      0x20   //Puts DAC in powerdown mode: 1k to GND
#define PD_DACA_100K_TO_GND    0x40   //Puts DAC in powerdown mode: 100k to GND
#define PD_DACA_THREE_STATE    0x60   //Puts DAC in powerdown mode: Three state

//SOFTWARE RESET
#define REG_SOFTWARE_RESET   0x80

//------------------------
// Internal Function declarations
//------------------------

void InitializeAD5693R(void);
void LdacInitialization(void);
void WriteData(unsigned int commandmode,unsigned int Data,unsigned char addr);
void UpdateDacReg(void);
void PowerDownReg(unsigned int DACAmode,unsigned char addr);
void SoftwareReset(unsigned char addr);
void InternalReferenceSetup(unsigned int IntRefState,unsigned char addr);
void OutputAmplifierGain(unsigned int OutputGain,unsigned char addr);
void ReadBackEnable(unsigned char addr);


#endif

