/********************************************************************************
 Author : Gowrishankar (gowrishankar.ashok@analog.com)
          India Applications Support Team

 Date : July 2014

 File name : ADuCM360Driver.c

 Description :

 Hardware plateform : ADuCM360
********************************************************************************/
#include <stdio.h>
#include <string.h>
#include "ADuCM360.h"
#include "ADuCM360Driver.h"

#include "DioLib.h"
#include "ClkLib.h"
#include "WdtLib.h"
#include "RstLib.h"
#include "I2cLib.h"
#include "UrtLib.h"




// Delay Function
void Delay(unsigned long int DelayTime)			  //  Delay Function
{ 
	unsigned char i;

	while(DelayTime>0)
	{ 
		for(i=0;i<32;i++) 
		{
			;
		}
		DelayTime--;
	}
}


// Initialise ADuCM360
void ADuCM360Initialise(void)									//  Initialising the controller
{
	 WdtCfg(T3CON_PRE_DIV1,T3CON_IRQ_EN,T3CON_PD_DIS);      // Disable Watchdog timer resets
   DioCfg(pADI_GP2,0x5);																	// Configure I2C ports
	
   //Disable clock to unused peripherals
   ClkDis(CLKDIS_DISPWMCLK|
      CLKDIS_DIST0CLK|CLKDIS_DIST1CLK|CLKDIS_DISDACCLK);  // Disable unused clock
   ClkCfg(CLK_CD0,CLK_HF,CLKSYSDIV_DIV2EN_DIS,CLK_UCLKCG);// Select CD0 for CPU clock - 16Mhz clock
   ClkSel(CLK_CD0,CLK_CD0,CLK_CD0,CLK_CD7);               // Select CD0 for I2C clocks
	
   ////Configure Port 2 pins for I2C operation
	 DioCfgPin(pADI_GP2,PIN0,1);                           // Configure P2.0 as SCL
	 DioCfgPin(pADI_GP2,PIN1,1);                           // Configure P2.1 as SDA 


	  I2cMCfg(0,I2CMCON_IENCMP_EN|
	  I2CMCON_IENNACK_EN|I2CMCON_IENALOST_EN|
	  I2CMCON_IENTX_EN|I2CMCON_IENRX_EN,I2CMCON_MAS_EN);
	
	 I2cBaud(0x4E,0x4F);                                     // Confiure I2C baud rate for 100kHz
	 I2cFifoFlush(0,1);
	 I2cSIDCfg(0x98,0x9C,0x98,0x9C);
	 
	 //UARTINIT ();           // Initialise UART

		//NVIC_EnableIRQ(UART_IRQn); //Enable UART interrupt
}


/**
	@brief void ADuCM360GpioOutput  (unsigned char  GpioNo, unsigned char OutputValue)
	- Configures the GPIO's as output based on pin assigned to the Controllers
		@param GpioNo : Pin number XY, X - Port number, Y - Pin Number
		@ - no return value
**/
void ADuCM360GpioOutput(unsigned char  GpioNo, unsigned char OutputValue)
{
	unsigned char PortNo  =  GpioNo  & 0xF0;
	unsigned char PinNo  =  GpioNo  & 0x0F;
	switch(PortNo)
	{	
		case 0x00:
				if(OutputValue == 0x1)
					pADI_GP0->GPSET =  (1<< PinNo);
				else if(OutputValue == 0x0)
					pADI_GP0->GPCLR =  (1<< PinNo);
				break;
				
		case 0x10:
				if(OutputValue == 0x1)
					pADI_GP1->GPSET =  (1<< PinNo);
				else if(OutputValue == 0x0)
					pADI_GP1->GPCLR =  (1<< PinNo);
				break;
				
		case 0x20: 
				if(OutputValue == 0x1)
					pADI_GP2->GPSET =  (1<< PinNo);
				else if(OutputValue == 0x0)
					pADI_GP2->GPCLR =  (1<< PinNo);
				break;
	}
	
}


/**
	@brief void ADuCM360GpioInput  (unsigned char  GpioNo)
	- Configures the GPIO's as Input based on pin assigned to the Controllers
		@param GpioNo : Pin number XY, X - Port number, Y - Pin Number
		@ - no return value
**/
char ADuCM360GpioInput(unsigned char  GpioNo)
{
	unsigned char PortNo  =  GpioNo  & 0xF0;
	unsigned char PinNo  =  GpioNo  & 0x0F;
	int inputbit = 0;
	switch(PortNo)
	{
		case 0x00:
			if((1<<PinNo) == (pADI_GP0->GPIN & (1<<PinNo)))
				inputbit= 1;
			else
				inputbit = 0;
			
		case 0x10:
			if((1<<PinNo) == (pADI_GP1->GPIN & (1<<PinNo)))
				inputbit= 1;
			else
				inputbit = 0;
			
		case 0x20:
			if((1<<PinNo) == (pADI_GP2->GPIN & (1<<PinNo)))
				inputbit= 1;
			else
				inputbit = 0;
		default:
				break;
		}
		return(inputbit);	
}


/**
	@brief: void I2cFunction(unsigned int OutputBuff[],unsigned int InputBuff[], unsigned int NoOfBytes, unsigned char Mode, unsigned char address)
	- Perform I2C communication
	@param: OutputBuff[]
					- Array containing Data that has to be sent using I2C
	@param: InputBuff[]
					- Array containing Data received using I2C
	@param: NoOfBytes
					- No of bytes need to be transferred
	@param: Mode: ( Send, Receive )
					- Send: to send data
					- Receive: to receive data
	@param: address
					- Address of the target device
**/
void I2cFunction(unsigned int OutputBuff[],unsigned int InputBuff[], unsigned int NoOfBytes, unsigned char Mode, unsigned char address)
{
	unsigned char addr,i;

	addr = address;
	
	
	if(Mode == 0)
	{
		
		for(i=0;i<(NoOfBytes);i++)
		{
		 	pADI_I2C->I2CADR0 = addr;
		  I2cTx(0,OutputBuff[i]);
			while(((I2cSta(0)) & 0x0004) != 0x0004)
			{
				;
			}
		}
	}
	
	else
	{
		I2cMRdCfg(addr,2,DISABLE);
		while(((I2cSta(0)) & 0x0008) != 0x0008)
		{
			;
		}
    	InputBuff[0] = I2cRx(0);
	}
}





